@@ -4,20 +4,9 @@
 #define LOGIN_ACCESS
 #define PASSWD_FALLBACK
 
-/* Testing/bg. If this works these symbols should be unifdef:ed */
-#define SYSV_ENV
-#define ENV_USER
-
 #include "config.h"
 #include "protos.h"
 
-/* Any better way to test this? */
-#if SunOS == 5
-/* #define SYSV_SHADOW done below */
-/* #define SYSV_ENV done above */
-/* #define ENV_USER done above */
-#endif
-
 /* Any better way to test NO_MOTD? */
 #if (SunOS == 5) || defined(__hpux)
 #define NO_MOTD
@@ -169,6 +158,12 @@ extern int optind, opterr;
 #include <usersec.h>
 #endif /* HAVE_USERSEC_H */
 
+#ifndef PRIO_PROCESS
+#define PRIO_PROCESS 0
+#endif
+
+#include <roken.h>
+
 #include <des.h>
 #include <krb.h>
 #include <kafs.h>
@@ -215,30 +210,37 @@ int forkpty ();
 #define MAX(a, b) ((a) > (b) ? (a) : (b))
 #endif
 
-char *getusershell __P((void));
-
 char *crypt __P((const char *, const char *));
 
 void stty_default __P((void));
 
-#ifndef NeXT
-typedef RETSIGTYPE (*SigAction)(/* int??? */);
-
-SigAction signal(int iSig, SigAction pAction);
-#endif
-
 int utmpx_login(char *line, char *user, char *host);
 
 void sysv_newenv(int argc, char **argv, struct passwd *pwd,
 		 char *term, int pflag);
 
-#ifndef HAVE_SETENV
-int setenv(const char *var, const char *val, int rewrite);
-#endif
-
 int login_access(char *user, char *from);
 #ifndef HAVE_IRUSEROK
 int iruserok(u_int32_t raddr, int superuser, const char *ruser,
 	     const char *luser);
 #endif
 void fatal(int f, const char *msg, int syserr);
+
+extern int LEFT_JUSTIFIED;
+int des_enc_read(int fd,char *buf,int len,des_key_schedule sched,
+	des_cblock *iv);
+int des_enc_write(int fd,char *buf,int len,des_key_schedule sched,
+	des_cblock *iv);
+
+void sysv_defaults(void);
+void utmp_login(char *tty, char *username, char *hostname);
+void	 sleepexit __P((int));
+
+#ifndef HAVE_SETPRIORITY
+#define setpriority(which, who, niceval) 0
+#endif
+
+#ifndef HAVE_GETPRIORITY
+#define getpriority(which, who) 0
+#endif
+
