@@ -35,7 +35,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: kcmd.c,v 1.5 1996/01/02 15:55:41 bg Exp $");
+RCSID("$Id: kcmd.c,v 1.6 1996/03/24 18:55:37 bg Exp $");
 
 #define	START_PORT	5120	 /* arbitrary */
 
@@ -76,7 +76,6 @@ kcmd(int *sock, char **ahost, u_int16_t rport, char *locuser, char *remuser, cha
     CREDENTIALS *cred, Key_schedule schedule, MSG_DAT *msg_data, struct sockaddr_in *laddr, struct sockaddr_in *faddr, int32_t authopts)
 {
 	int s, timo = 1, pid;
-	sigset_t oldmask;
 	struct sockaddr_in sin, from;
 	char c;
 #ifdef ATHENA_COMPAT
@@ -104,13 +103,6 @@ kcmd(int *sock, char **ahost, u_int16_t rport, char *locuser, char *remuser, cha
 	if (realm == NULL || realm[0] == '\0')
 		realm = krb_realmofhost(host_save);
 
-	{
-	    sigset_t sigmsk;
-	    sigemptyset(&sigmsk);
-	    sigaddset(&sigmsk, SIGURG);
-	    if (sigprocmask(SIG_BLOCK, &sigmsk, &oldmask) != 0)
-	        perror("sigprocmask");
-	}
 	for (;;) {
 		s = getport(&lport);
 		if (s < 0) {
@@ -119,8 +111,6 @@ kcmd(int *sock, char **ahost, u_int16_t rport, char *locuser, char *remuser, cha
 					"kcmd(socket): All ports in use\n");
 			else
 				perror("kcmd: socket");
-			if (sigprocmask(SIG_SETMASK, &oldmask, 0) != 0)
-			    perror("sigprocmask");
 			return (-1);
 		}
 #ifdef F_SETOWN
@@ -167,8 +157,6 @@ kcmd(int *sock, char **ahost, u_int16_t rport, char *locuser, char *remuser, cha
 #endif /* !(defined(ultrix) || defined(sun)) */
 		if (errno != ECONNREFUSED)
 			perror(hp->h_name);
-		if (sigprocmask(SIG_SETMASK, &oldmask, 0) != 0)
-		    perror("sigprocmask");
 		return (-1);
 	}
 	lport--;
@@ -257,8 +245,6 @@ kcmd(int *sock, char **ahost, u_int16_t rport, char *locuser, char *remuser, cha
 		status = -1;
 		goto bad2;
 	}
-	if (sigprocmask(SIG_SETMASK, &oldmask, 0) != 0)
-	    perror("sigprocmask");
 	*sock = s;
 	return (KSUCCESS);
 bad2:
@@ -266,7 +252,5 @@ bad2:
 		(void) close(*fd2p);
 bad:
 	(void) close(s);
-	if (sigprocmask(SIG_SETMASK, &oldmask, 0) != 0)
-	    perror("sigprocmask");
 	return (status);
 }
