@@ -39,7 +39,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login.c,v 1.45 1996/03/24 15:13:33 bg Exp $");
+RCSID("$Id: login.c,v 1.60 1996/04/24 09:19:14 bg Exp $");
 
 #ifdef	xSKEY			/* Don't bother to find this header file. */
 #include <skey.h>
@@ -57,10 +57,9 @@ void	 getloginname __P((int));
 void	 motd __P((void));
 int	 rootterm __P((char *));
 void	 sigint __P((int));
-void	 sleepexit __P((int));
 char	*stypeof __P((char *));
 void	 timedout __P((int));
-int	 doremotelogin __P((char *));
+static int	 doremotelogin __P((char *));
 void     login_fbtab __P((char *, uid_t, gid_t));
 #ifdef KERBEROS
 int	 klogin __P((struct passwd *, char *, char *, char *));
@@ -93,28 +92,6 @@ char	term[64], *envinit[1], *hostname, *username, *tty;
 
 static  char rusername[100], lusername[100];
 
-#ifndef HAVE_GETDTABLESIZE
-int
-getdtablesize()
-{
-#ifdef RLIMIT_NOFILE
-  struct rlimit lim;
-
-  if (getrlimit(RLIMIT_NOFILE, &lim) != -1)
-    return lim.rlim_cur;
-#endif
-  return NOFILE;		/* Fallback solution */
-}
-#endif
-
-#ifndef HAVE_SETPRIORITY
-int
-setpriority(int which, int who, int niceval)
-{
-  return 0;			/* Bloody Psoriasis */
-}
-#endif
-
 static int
 change_passwd(struct passwd  *who)
 {
@@ -142,8 +119,6 @@ main(argc, argv)
 	char *argv[];
 {
 	struct group *gr;
-	struct stat st;
-	struct utmp utmp;
 	int ask, ch, cnt, fflag, hflag, pflag, quietlog, rootlogin, rval;
 	int rflag;
 	int changepass = 0;
@@ -186,7 +161,7 @@ main(argc, argv)
 	 */
 	*full_hostname = '\0';
 	domain = NULL;
-	if (gethostname(localhost, sizeof(localhost)) < 0)
+	if (k_gethostname(localhost, sizeof(localhost)) < 0)
 		syslog(LOG_ERR, "couldn't get local hostname: %m");
 	else
 		domain = strchr(localhost, '.');
@@ -260,11 +235,9 @@ main(argc, argv)
                 username = lusername;
                 ask = 0;
 	      } else
-#ifdef SYSV_ENV /* Pick up environment stuff after logging in. */
         if (*argv && strchr(*argv, '=')) {
                 ask = 1;
 	      } else
-#endif /* SYSV_ENV */
         if (*argv && strcmp(*argv, "-") == 0) {
                 argc--;
                 argv++;
@@ -273,10 +246,8 @@ main(argc, argv)
 	if (*argv) {
 		username = *argv;
 		ask = 0;
-#ifdef SYSV_ENV /* Pick up additional environment stuff after logging in. */
                 argc--;
                 argv++;
-#endif /* SYSV_ENV */
         } else if ((ttyprompt = getenv("TTYPROMPT")) && *ttyprompt) {
                 getloginname(0);
                 ask = 0;
@@ -299,12 +270,13 @@ main(argc, argv)
 	        (void)sprintf(tname, "%s??", _PATH_TTY);
 	        ttyn = tname;
 	}
-        if (tty = strchr(ttyn + 1, '/'))
+        if ((tty = strchr(ttyn + 1, '/')))
 	        ++tty;
         else
 	        tty = ttyn;
 
 	for (cnt = 0;; ask = 1) {
+	        char prompt[128];
 		if (ask) {
 			fflag = 0;
 			getloginname(1);
@@ -338,6 +310,13 @@ main(argc, argv)
 		else
 			salt = "xx";
 
+		if (pwd && pwd->pw_uid == 0 && strcmp("root", username) != 0)
+		  {
+		    pwd = 0;
+		    syslog(LOG_ALERT,
+			   "NIS attack, user %s has uid 0", username);
+		  }
+
 		/*
 		 * if we have a valid account name, and it doesn't have a
 		 * password, or the -f option was specified and the caller
@@ -362,17 +341,18 @@ main(argc, argv)
 
 		(void)setpriority(PRIO_PROCESS, 0, -4);
 
+		sprintf(prompt, "%s's Password: ", username);
 #ifdef	SKEY
 		permit_passwd = skeyaccess(username, tty,
 					   hostname ? full_hostname : NULL,
 					   NULL);
-		p = (char *) skey_getpass("Password:", pwd, permit_passwd);
+		p = (char *) skey_getpass(prompt, pwd, permit_passwd);
 		strncpy(ep,
 			(char *)skey_crypt(p, salt, pwd, permit_passwd),
 			sizeof(ep));
 		ep[sizeof(ep) - 1] = 0;
 #else
-		p = getpass("Password:");
+		p = getpass(prompt);
 		strncpy(ep, crypt(p, salt), sizeof(ep));
 		ep[sizeof(ep) - 1] = 0;
 #endif
@@ -497,40 +477,12 @@ main(argc, argv)
         /*
          * Update the utmp files, both BSD and SYSV style.
          */
-	memset((void *)&utmp, 0, sizeof(utmp));
-	(void)time(&utmp.ut_time);
-	(void)strncpy(utmp.ut_line, tty, sizeof(utmp.ut_line));
-	(void)strncpy(utmp.ut_name, username, sizeof(utmp.ut_name));
-# ifdef HAVE_UT_USER
-	(void)strncpy(utmp.ut_user, username, sizeof(utmp.ut_user));
-# endif
-	if (hostname) {
-# ifdef HAVE_UT_ADDR
-		struct hostent *he;
-		if ((he = gethostbyname(hostname)))
-			memcpy(&utmp.ut_addr, he->h_addr_list[0],
-			       sizeof(utmp.ut_addr));
-# endif
-# ifdef HAVE_UT_HOST
-		(void)strncpy(utmp.ut_host, hostname, sizeof(utmp.ut_host));
-# endif
-	}
-# ifdef HAVE_UT_TYPE
-	utmp.ut_type = USER_PROCESS;
-# endif
-# ifdef HAVE_UT_PID
-	utmp.ut_pid = getpid();
-# endif
-# ifdef HAVE_UT_ID
-	strncpy(utmp.ut_id, ttyn + sizeof("/dev/tty") - 1, sizeof(utmp.ut_id));
-# endif
         if (utmpx_login(tty, username, hostname ? hostname : "") != 0
 	    && !fflag) {
                 printf("No utmpx entry.  You must exec \"login\" from the lowest level \"sh\".\n");
                 sleepexit(0);
         }
-	login(&utmp);
-
+	utmp_login(ttyn, username, hostname ? hostname : "");
 	dolastlog(quietlog);
 
 	/*
@@ -556,24 +508,10 @@ main(argc, argv)
          * some variables are always clobbered. We add code to make sure
          * that LD_* and IFS are never preserved.
          */
-#ifdef SYSV_ENV
 	if (term[0] == '\0')
 		(void)strncpy(term, stypeof(tty), sizeof(term));
         /* set up a somewhat censored environment. */
         sysv_newenv(argc, argv, pwd, term, pflag);
-#else /* SYSV_ENV */
-	/* Destroy environment unless user has requested its preservation. */
-	if (!pflag)
-		environ = envinit;
-	(void)setenv("HOME", pwd->pw_dir, 1);
-	(void)setenv("SHELL", pwd->pw_shell, 1);
-	if (term[0] == '\0')
-		(void)strncpy(term, stypeof(tty), sizeof(term));
-	(void)setenv("TERM", term, 0);
-	(void)setenv("LOGNAME", pwd->pw_name, 1);
-	(void)setenv("USER", pwd->pw_name, 1);
-	(void)setenv("PATH", _PATH_DEFPATH, 0);
-#endif /* SYSV_ENV */
 #ifdef KERBEROS
 	if (krbtkfile_env)
 		(void)setenv("KRBTKFILE", krbtkfile_env, 1);
@@ -613,6 +551,7 @@ main(argc, argv)
          * motd and mail stuff up to the shell startup file.
          */
 	if (!quietlog) {
+	        struct stat st;
 #if 0
 		(void)printf("%s\n\t%s  %s\n\n",
 	    "Copyright (c) 1980, 1983, 1986, 1988, 1990, 1991, 1993, 1994",
@@ -661,10 +600,16 @@ main(argc, argv)
 #endif /* HAVE_SETPCRED */
 
 	/* Discard permissions last so can't get killed and drop core. */
-	if (rootlogin)
-		(void) setuid(0);
-	else
-		(void) setuid(pwd->pw_uid);
+	{
+	    int uid = rootlogin ? 0 : pwd->pw_uid;
+	    if(setuid(uid) != 0){
+		fprintf(stderr, "Failed to setuid(%d): %s\n", 
+			uid, k_strerror(errno));
+		if(!rootlogin)
+		    exit(1);
+	    }
+	}
+		       
 
 	/*
          * After dropping privileges and after cleaning up the environment,
@@ -921,7 +866,9 @@ stypeof(ttyid)
     }
 }
 
-void getstr(char *buf, int cnt, char *err)
+static
+void
+getstr(char *buf, int cnt, char *err)
 {
         char ch;
  
@@ -936,15 +883,35 @@ void getstr(char *buf, int cnt, char *err)
         } while (ch);
 }
 
-int doremotelogin(char *host)
+/*
+ * Some old rlogind's unknowingly pass remuser, locuser and
+ * terminal_type/speed so we need to take care of that part of the
+ * protocol here. Also, we can't make a getpeername(2) on the socket
+ * so we have to trust that rlogind resolved the name correctly.
+ */
+
+static
+int
+doremotelogin(char *host)
 {
+        int code;
+        char *cp;
+
         getstr(rusername, sizeof (rusername), "remuser");
         getstr(lusername, sizeof (lusername), "locuser");
         getstr(term, sizeof(term), "Terminal type");
+	cp = strchr(term, '/');
+	if (cp != 0)
+		*cp = 0;	/* For now ignore speed/bg */
         pwd = getpwnam(lusername);
         if (pwd == NULL)
                 return(-1);
-        return(ruserok(host, (pwd->pw_uid == 0), rusername, lusername));
+        code = ruserok(host, (pwd->pw_uid == 0), rusername, lusername);
+	if (code == 0)
+	  syslog(LOG_NOTICE,
+		 "Warning: An old rlogind accepted login probably from host %s",
+		 host);
+	return(code);
 }
  
 void
@@ -955,30 +922,3 @@ sleepexit(int eval)
 	exit(eval);
 }
 
-void
-login(struct utmp *ut)
-{
-        int fd;
-
-#ifdef HAVE_SETUTENT
-	utmpname(_PATH_UTMP);
-	setutent();
-	pututline(ut);
-	endutent();
-#else
-#ifdef HAVE_TTYSLOT
-        int tty;
-        tty = ttyslot();
-        if (tty > 0 && (fd = open(_PATH_UTMP, O_WRONLY, 0)) >= 0) {
-                (void)lseek(fd, (long)(tty * sizeof(struct utmp)), SEEK_SET);
-                (void)write(fd, (char *)ut, sizeof(struct utmp));
-                (void)close(fd);
-        }
-#endif /* HAVE_TTYSLOT */
-#endif /* HAVE_SETUTENT */
-
-        if ((fd = open(_PATH_WTMP, O_WRONLY|O_APPEND, 0)) >= 0) {
-                (void)write(fd, (char *)ut, sizeof(struct utmp));
-                (void)close(fd);
-        }
-}
