@@ -35,7 +35,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rcp.c,v 1.19 1996/03/24 06:56:41 assar Exp $");
+RCSID("$Id: rcp.c,v 1.22 1996/03/28 13:46:33 bg Exp $");
 
 /* Globals */
 char *__progname;
@@ -313,7 +313,7 @@ syserr:			run_err("%s: %s", name, k_strerror(errno));
 			 * versions expecting microseconds.
 			 */
 			(void)sprintf(buf, "T%ld 0 %ld 0\n",
-			    stb.st_mtime, stb.st_atime);
+			    (long)stb.st_mtime, (long)stb.st_atime);
 			(void)des_write(rem, buf, strlen(buf));
 			if (response() < 0)
 				goto next;
@@ -374,7 +374,7 @@ rsource(char *name, struct stat *statp)
 		last++;
 	if (pflag) {
 		(void)sprintf(path, "T%ld 0 %ld 0\n",
-		    statp->st_mtime, statp->st_atime);
+		    (long)statp->st_mtime, (long)statp->st_atime);
 		(void)des_write(rem, path, strlen(path));
 		if (response() < 0) {
 			closedir(dirp);
@@ -453,7 +453,7 @@ again:
 		    SERVICE_NAME,
 		    dest_realm,
 		    (CREDENTIALS *) NULL, /* credentials not used */
-		    (bit_64 *) NULL, /* key schedule not used */
+		    0,		/* key schedule not used */
 		    (MSG_DAT *) NULL, /* MSG_DAT not used */
 		    (struct sockaddr_in *) NULL, /* local addr not used */
 		    (struct sockaddr_in *) NULL, /* foreign addr not used */
@@ -907,7 +907,7 @@ main(int argc, char **argv)
 			break;
 		case 'x':
 			doencrypt = 1;
-			{ extern int LEFT_JUSTIFIED; LEFT_JUSTIFIED = 1; };
+			LEFT_JUSTIFIED = 1;
 			break;
 		case 'p':
 			pflag = 1;
