@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogind.c,v 1.47 1996/03/24 16:38:03 bg Exp $");
+RCSID("$Id: rlogind.c,v 1.50 1996/04/24 07:41:11 assar Exp $");
 
 #include <termios.h>
 
@@ -332,7 +332,7 @@ int main(int argc, char **argv)
 
 int	child;
 int	netf;
-char	line[MAXPATHLEN];
+char	line[MaxPathLen];
 int	confirmed;
 
 struct winsize win = { 0, 0, 0, 0 };
@@ -712,8 +712,10 @@ int do_rlogin(struct sockaddr_in *dest)
 	if (pwd == NULL)
 		return (-1);
 	if (pwd->pw_uid == 0)
+	  {
+	  	syslog(LOG_ALERT, "NIS attack, user %s has uid 0", lusername);
 		return (-1);
-	/* XXX why don't we syslog() failure? */
+	  }
 	return (iruserok(dest->sin_addr.s_addr, 0, rusername, lusername));
 }
 
@@ -808,7 +810,7 @@ int do_krb_login(struct sockaddr_in *dest)
 			authopts, 0,
 			ticket, "rcmd",
 			instance, dest, (struct sockaddr_in *) 0,
-			kdata, "", (bit_64 *) 0, version);
+			kdata, "", 0, version);
 
 	if (rc != KSUCCESS)
 		return (rc);
@@ -820,6 +822,11 @@ int do_krb_login(struct sockaddr_in *dest)
 	pwd = getpwnam(lusername);
 	if (pwd == NULL)
 		return (-1);
+	if (pwd->pw_uid == 0 && strcmp("root", lusername) != 0)
+	  {
+	    syslog(LOG_ALERT, "NIS attack, user %s has uid 0", lusername);
+	    return (-1);
+	  }
 
 	/* returns nonzero for no access */
 	if (kuserok(kdata, lusername) != 0)
