@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rshd.c,v 1.22 1996/03/24 06:56:48 assar Exp $");
+RCSID("$Id: rshd.c,v 1.25 1996/04/19 10:21:37 bg Exp $");
 
 #include <sys/ioctl.h>
 
@@ -144,6 +144,7 @@ main(argc, argv)
 		syslog(LOG_WARNING, "setsockopt (SO_LINGER): %m");
 	doit(&from);
 	/* NOTREACHED */
+	return 0;
 }
 
 char	username[20] = "USER=";
@@ -356,7 +357,7 @@ doit(fromp)
 			rc = krb_recvauth(authopts, 0, ticket, "rcmd",
 				instance, &fromaddr,
 				(struct sockaddr_in *) 0,
-				kdata, "", (bit_64 *) 0, version);
+				kdata, "", 0, version);
 		if (rc != KSUCCESS) {
 			error("Kerberos authentication failure: %s\n",
 				  krb_get_err_text(rc));
@@ -377,6 +378,13 @@ doit(fromp)
 			errorstr = "Login incorrect.\n";
 		goto fail;
 	}
+	if (pwd->pw_uid == 0 && strcmp("root", locuser) != 0)
+	  {
+	    syslog(LOG_ALERT, "NIS attack, user %s has uid 0", locuser);
+	    if (errorstr == NULL)
+	      errorstr = "Login incorrect.\n";
+	    goto fail;
+	  }
 	if (chdir(pwd->pw_dir) < 0) {
 		(void) chdir("/");
 #ifdef notdef
@@ -492,12 +500,12 @@ fail:
 				if (doencrypt) {
 					wready = writeto;
 					if (select(nfd, &ready,
-					    &wready, (fd_set *) 0,
+					    &wready, 0,
 					    (struct timeval *) 0) < 0)
 						break;
 				} else
-					if (select(nfd, &ready, (fd_set *)0,
-					  (fd_set *)0, (struct timeval *)0) < 0)
+					if (select(nfd, &ready, 0,
+						   0, (struct timeval *)0) < 0)
 						break;
 				if (FD_ISSET(s, &ready)) {
 					int	ret;
@@ -689,7 +697,7 @@ local_domain(h)
 	char *p1, *p2;
 
 	localhost[0] = 0;
-	(void) gethostname(localhost, sizeof(localhost));
+	(void) k_gethostname(localhost, sizeof(localhost));
 	p1 = topdomain(localhost);
 	p2 = topdomain(h);
 	if (p1 == NULL || p2 == NULL || !strcasecmp(p1, p2))
