@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: su.c,v 1.35 1996/03/24 06:56:50 assar Exp $");
+RCSID("$Id: su.c,v 1.42 1996/04/24 09:19:16 bg Exp $");
 
 #ifdef SYSV_SHADOW
 #include "sysv_shadow.h"
@@ -41,25 +41,9 @@ RCSID("$Id: su.c,v 1.35 1996/03/24 06:56:50 assar Exp $");
 
 static int kerberos(char *username, char *user, int uid);
 static int chshell(char *sh);
-static char *ontty();
+static char *ontty(void);
 static int koktologin(char *name, char *realm, char *toname);
 
-#ifndef HAVE_SETPRIORITY
-int
-setpriority(int which, int who, int niceval)
-{
-  return 0;			/* Bloody Psoriasis */
-}
-#endif
-
-#ifndef HAVE_GETPRIORITY
-int
-getpriority(int which, int who)
-{
-  return 0;			/* Bloody Psoriasis */
-}
-#endif
-
 /* Handle '-' option after all the getopt options */
 #define	ARGSTR	"Kflmi:"
 
@@ -67,7 +51,6 @@ int use_kerberos = 1;
 char *root_inst = "root";
 
 static int chshell();
-static char *ontty();
 
 int
 main(argc, argv)
@@ -119,6 +102,14 @@ main(argc, argv)
 	}
 	argv += optind;
 
+	if (use_kerberos)
+	  {
+	    int fd = open(KEYFILE, O_RDONLY);
+	    if (fd >= 0)
+	      close(fd);
+	    else
+	      use_kerberos = 0;
+	  }
 	errno = 0;
 	prio = getpriority(PRIO_PROCESS, 0);
 	if (errno)
@@ -154,6 +145,12 @@ main(argc, argv)
 		fprintf(stderr, "su: unknown login %s\n", user);
 		exit(1);
 	}
+	if (pwd->pw_uid == 0 && strcmp("root", user) != 0)
+	  {
+	    syslog(LOG_ALERT, "NIS attack, user %s has uid 0", user);
+	    fprintf(stderr, "su: unknown login %s\n", user);
+	    exit(1);
+	  }
 
 	if (!use_kerberos || kerberos(username, user, pwd->pw_uid)) {
 #ifndef PASSWD_FALLBACK
@@ -187,7 +184,9 @@ main(argc, argv)
 	    }
 	  /* if target requires a password, verify it */
 	  if (*pwd->pw_passwd) {
-	    p = getpass("Password:");
+	    char prompt[128];
+	    sprintf(prompt, "%s's Password: ", pwd->pw_name);
+	    p = getpass(prompt);
 	    if (strcmp(pwd->pw_passwd, crypt(p, pwd->pw_passwd))) {
 	      fprintf(stderr, "Sorry\n");
 	      syslog(LOG_AUTH|LOG_WARNING,
@@ -316,7 +315,7 @@ chshell(char *sh)
 }
 
 static char *
-ontty()
+ontty(void)
 {
 	char *p;
 	static char buf[MaxPathLen + 4];
@@ -341,7 +340,9 @@ kerberos(char *username, char *user, int uid)
 	if (krb_get_lrealm(lrealm, 1) != KSUCCESS)
 		return (1);
 	if (koktologin(username, lrealm, user) && !uid) {
+#ifndef PASSWD_FALLBACK
 		(void)fprintf(stderr, "su: not in %s's ACL.\n", user);
+#endif
 		return (1);
 	}
 	sprintf(krbtkfile, "%s_%s_to_%s_%d", TKT_ROOT, username, user,
@@ -359,15 +360,20 @@ kerberos(char *username, char *user, int uid)
 	 * We should have a way to set the ticket lifetime,
 	 * with a system default for root.
 	 */
-	printf("User's %s%s%s@%s ",
-	       (uid == 0 ? username : user),
-	       (uid == 0 ? "." : ""),
-	       (uid == 0 ? root_inst : ""),
-	       lrealm);
-	fflush(stdout);
-	kerno = krb_get_pw_in_tkt((uid == 0 ? username : user),
-		(uid == 0 ? root_inst : ""), lrealm,
-	    	"krbtgt", lrealm, DEFAULT_TKT_LIFE, 0);
+	{
+	  char prompt[128];
+	  char *passw;
+	  sprintf(prompt, "%s%s%s@%s's Password: ",
+		  (uid == 0 ? username : user),
+		  (uid == 0 ? "." : ""),
+		  (uid == 0 ? root_inst : ""),
+		  lrealm);
+	  passw = getpass(prompt);
+	  kerno = krb_get_pw_in_tkt((uid == 0 ? username : user),
+				    (uid == 0 ? root_inst : ""), lrealm,
+				    "krbtgt", lrealm, DEFAULT_TKT_LIFE, passw);
+	  bzero(passw, strlen(passw));
+	}
 
 	if (kerno != KSUCCESS) {
 		if (kerno == KDC_PR_UNKNOWN) {
@@ -392,7 +398,7 @@ kerberos(char *username, char *user, int uid)
 
 	(void)setpriority(PRIO_PROCESS, 0, -2);
 
-	if (gethostname(hostname, sizeof(hostname)) == -1) {
+	if (k_gethostname(hostname, sizeof(hostname)) == -1) {
 		perror("su: gethostname");
 		dest_tkt();
 		return (1);
