@@ -8,7 +8,7 @@
 
 #include "kauth.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/appl/kauth/kauth.c,v 1.47 1996/03/24 23:42:41 d91-jda Exp $");
+RCSID("$Id: kauth.c,v 1.55 1996/04/25 19:16:32 d91-jda Exp $");
 
 char *prog;
 static char inst[100];
@@ -18,6 +18,7 @@ static char srvtab[MaxPathLen + 1];
 static int lifetime = DEFAULT_TKT_LIFE;
 static char remote_tktfile[MaxPathLen + 1];
 static char remoteuser[100];
+static char *cell = 0;
 
 static void
 usage()
@@ -76,17 +77,13 @@ renew(int sig)
     fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
   else if (k_hasafs())
     {
-      if ((code = k_afsklog(0, realm)) != 0 && code != KDC_PR_UNKNOWN) {
+      if ((code = k_afsklog(cell, NULL)) != 0 && code != KDC_PR_UNKNOWN) {
         fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
       }
     }
 
   alarm(krb_life_to_time(0, lifetime)/2 - 60);
-#ifdef VOID_RETSIGTYPE
-  return;
-#else
-  return (RETSIGTYPE)0;
-#endif
+  SIGRETURN(0);
 }
 
 static int
@@ -134,13 +131,13 @@ main(argc, argv)
   int code, more_args;
   int ret;
   int c;
-  char *cell = 0;
   char *file;
   int pflag = 0;
   char passwd[100];
   des_cblock key;
   char **host;
   int nhost;
+  char tf[MaxPathLen];
 
   if ((file =  getenv("KRBTKFILE")) == 0)
     file = TKT_FILE;  
@@ -252,13 +249,26 @@ main(argc, argv)
   if (realm[0] == 0)
     if (krb_get_lrealm(realm, 1) != KSUCCESS)
       strcpy(realm, "NO.DEFAULT.REALM");
-  
+
+  if (more_args) {
+    int f;
+
+    do{
+      sprintf(tf, "/tmp/tkt%d_%d", (int)getuid(), (int)(getpid()*time(0)));
+      f = open(tf, O_CREAT|O_EXCL|O_RDWR);
+    }while(f < 0);
+    close(f);
+    unlink(tf);
+    setenv("KRBTKFILE", tf, 1);
+    krb_set_tkt_string (tf);
+  }
+    
   if (srvtab[0])
     {
       signal(SIGALRM, renew);
 
 
-      code = read_service_key (name, inst, realm, 0, srvtab, &key);
+      code = read_service_key (name, inst, realm, 0, srvtab, (char *)&key);
       if (code == KSUCCESS)
 	code = krb_get_in_tkt(name, inst, realm, "krbtgt", realm, lifetime,
 			      key_to_key, NULL, key);
@@ -266,9 +276,11 @@ main(argc, argv)
     }
   else
     {
-      printf("User's %s%s%s@%s ", name, inst[0] ? "." : "", inst, realm);
-      fflush(stdout);
-      if (des_read_pw_string(passwd, sizeof(passwd)-1, "Password: ", 0))
+      char prompt[128];
+      sprintf(prompt,
+	      "%s%s%s@%s's Password: ",
+	      name, inst[0] ? "." : "", inst, realm);
+      if (des_read_pw_string(passwd, sizeof(passwd)-1, prompt, 0))
 	*passwd = '\0';
       des_string_to_key (passwd, &key);
       code = krb_get_in_tkt (name, inst, realm, "krbtgt", realm, lifetime,
@@ -292,7 +304,7 @@ main(argc, argv)
     {
       if (more_args)
         k_setpag();
-      if ((code = k_afsklog(cell, realm)) != 0 && code != KDC_PR_UNKNOWN)
+      if ((code = k_afsklog(cell, NULL)) != 0 && code != KDC_PR_UNKNOWN)
         fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
     }
 
