@@ -1,4 +1,4 @@
-/* $Id: kauth.h,v 1.2 1996/03/24 06:57:01 assar Exp $ */
+/* $Id: kauth.h,v 1.4 1996/04/29 11:57:36 bg Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -9,6 +9,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <signal.h>
+#include <fcntl.h>
 #include <errno.h>
 #include <unistd.h>
 #include <pwd.h>
@@ -36,6 +37,8 @@ extern int optind, opterr;
 #include <krb.h>
 #include <kafs.h>
 
+#include <roken.h>
+
 int rkinit (char *name, char *inst, char *realm, int lifetime,
 	    char *locuser, char *tktfile, des_cblock *key, char *hostname);
 
