@@ -9,16 +9,14 @@ static char copyright[] = "Copyright (c) 1990 Regents of the University of Calif
 static char SccsId[] = "@(#)@(#)pop_quit.c	2.1  2.1 3/18/91";
 #endif /* not lint */
 
-#include <stdio.h>
-#include <sys/types.h>
-#include "popper.h"
+#include <popper.h>
 
 /* 
  *  quit:   Terminate a POP session
  */
 
-int pop_quit (p)
-POP     *   p;
+int
+pop_quit (POP *p)
 {
     /*  Release the message information list */
     if (p->mlp) free ((char *)p->mlp);
