@@ -21,11 +21,36 @@
 #define RETURN_PATH_HANDLING
 #endif
 
-#define KERBEROS
+/* Common include files */
 
+#include <stdio.h>
+#include <stdarg.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
+#include <signal.h>
+#include <setjmp.h>
+#include <ctype.h>
+#include <fcntl.h>
+#include <pwd.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/file.h>
+#include <sys/time.h>
+#ifdef HAVE_SYS_RESOURCE_H
+#include <sys/resource.h>
+#endif
+#include <sys/wait.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <netdb.h>
+#include <arpa/inet.h>
 #include <syslog.h>
 #include "version.h"
 
+#define KERBEROS
+
 #ifdef KERBEROS
 #include <krb.h>
 #else
@@ -61,13 +86,30 @@
 #define POP_PRIORITY    LOG_NOTICE
 #define POP_DEBUG       LOG_DEBUG
 #define POP_LOGOPTS     0
-#define POP_MAILDIR     "/usr/spool/mail"
-#define POP_DROP        "/usr/spool/mail/.%s.pop"
+
+#ifdef HAVE_PATHS_H
+#include <paths.h>
+#endif
+#ifdef HAVE_MAILLOCK_H
+#include <maillock.h>
+#endif
+
+#if defined(KRB4_MAILDIR)
+#define POP_MAILDIR	KRB4_MAILDIR
+#elif defined(_PATH_MAILDIR)
+#define POP_MAILDIR     _PATH_MAILDIR
+#elif defined(MAILDIR)
+#define POP_MAILDIR	MAILDIR
+#else
+#define POP_MAILDIR	"/usr/spool/mail"
+#endif
+
+#define POP_DROP        POP_MAILDIR "/.%s.pop"
 	/* POP_TMPSIZE needs to be big enough to hold the string
 	 * defined by POP_TMPDROP.  POP_DROP and POP_TMPDROP
 	 * must be in the same filesystem.
 	 */
-#define POP_TMPDROP     "/usr/spool/mail/tmpXXXXXX"
+#define POP_TMPDROP     POP_MAILDIR "/tmpXXXXXX"
 #define POP_TMPSIZE	256
 #define POP_TMPXMIT     "/tmp/xmitXXXXXX"
 #define POP_OK          "+OK"
