@@ -33,6 +33,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
@@ -42,10 +43,6 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #define memmove(a,b,c) bcopy((b),(a),(c))
 #endif /* HAVE_MEMMOVE */
 
-#ifdef sun
-#include <malloc.h>
-#endif /* sun */
-
 #ifdef HESIOD
 #include <hesiod.h>
 /*
@@ -80,16 +77,22 @@ extern char *krb_realmofhost (/* char * */);
 extern int h_errno;
 #endif
 
-static int socket_connection (/* char *, int */);
-static char *getline (/* popserver */);
-static int sendline (/* popserver, char * */);
-static int fullwrite (/* int, char *, int */);
-static int getok (/* popserver */);
+static int socket_connection ( char *, int );
+static char *getline ( popserver );
+static int sendline ( popserver, char * );
+static int fullwrite ( int, char *, int );
+static int getok ( popserver );
 #if 0
-static int gettermination (/* popserver */);
+static int gettermination ( popserver );
 #endif
-static void pop_trash (/* popserver */);
-static char *find_crlf (/* char * */);
+static void pop_trash ( popserver );
+static char *find_crlf ( char * );
+static char *getline (popserver server);
+static int sendline (popserver server, char *line);
+static int fullwrite (int fd, char *buf, int nbytes);
+static int getok (popserver server);
+static void pop_trash (popserver server);
+static char *find_crlf (char *in_string);
 
 #define ERROR_MAX 80		/* a pretty arbitrary size */
 #define POP_PORT 110
@@ -588,7 +591,7 @@ pop_retrieve (server, message, markfrom)
       free (ptr);
       return (0);
     }
-}     
+}
 
 int
 pop_retrieve_first (server, message, response)
@@ -932,9 +935,7 @@ pop_quit (server)
  * 	into pop_error.
  */
 static int
-socket_connection (host, flags)
-     char *host;
-     int flags;
+socket_connection (char *host, int flags)
 {
   struct hostent *hostent;
   struct servent *servent;
@@ -1039,7 +1040,7 @@ socket_connection (host, flags)
       if (rem != KSUCCESS)
 	{
 	  strcpy (pop_error, KRB_ERROR);
-	  strncat (pop_error, krb_err_txt[rem],
+	  strncat (pop_error, krb_get_err_text(rem),
 		   ERROR_MAX - sizeof (KRB_ERROR));
 	  (void) close (sock);
 	  return (-1);
@@ -1068,8 +1069,7 @@ socket_connection (host, flags)
  * Side effects: Closes the connection on error.
  */
 static char *
-getline (server)
-     popserver server;
+getline (popserver server)
 {
 #define GETLINE_ERROR "Error reading from server: "
 
@@ -1191,9 +1191,7 @@ getline (server)
  * Side effects: Closes the connection on error.
  */
 static int
-sendline (server, line)
-     popserver server;
-     char *line;
+sendline (popserver server, char *line)
 {
 #define SENDLINE_ERROR "Error writing to POP server: "
   int ret;
@@ -1228,10 +1226,7 @@ sendline (server, line)
  * Return value: Same as write.  Pop_error is not set.
  */
 static int
-fullwrite (fd, buf, nbytes)
-     int fd;
-     char *buf;
-     int nbytes;
+fullwrite (int fd, char *buf, int nbytes)
 {
   char *cp;
   int ret;
@@ -1261,8 +1256,7 @@ fullwrite (fd, buf, nbytes)
  * Side effects: On failure, may make the connection unuseable.
  */
 static int
-getok (server)
-     popserver server;
+getok (popserver server)
 {
   char *fromline;
 
@@ -1351,8 +1345,7 @@ pop_close (server)
  * 	pop_close or pop_quit after this function has been called.
  */
 static void
-pop_trash (server)
-     popserver server;
+pop_trash (popserver server)
 {
   if (server->file >= 0)
     {
@@ -1373,8 +1366,7 @@ pop_trash (server)
    or 0 if it does not contain one.  */
 
 static char *
-find_crlf (in_string)
-     char *in_string;
+find_crlf (char *in_string)
 {
   while (1)
     {
