@@ -1,5 +1,5 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/appl/sample/sample_client.c,v $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/appl/sample/sample_client.c,v $
  * $Author: bg $
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology.
@@ -26,7 +26,7 @@
 
 #ifndef	lint
 static char rcsid_sample_client_c[] =
-"$Header: /src/packages/kth-krb/SourceRepository/krb4/appl/sample/sample_client.c,v 1.3 1996/03/11 09:21:46 bg Exp $";
+"$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/appl/sample/sample_client.c,v 1.3 1996/03/11 09:21:46 bg Exp $";
 #endif	lint
 
 #include <mit-copyright.h>
