@@ -1,5 +1,5 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/appl/sample/simple_server.c,v $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/appl/sample/simple_server.c,v $
  * $Author: bg $
  *
  * Copyright 1989 by the Massachusetts Institute of Technology.
@@ -13,7 +13,7 @@
 
 #ifndef	lint
 static char rcsid_simple_server_c[] =
-"Bones$Header: /src/packages/kth-krb/SourceRepository/krb4/appl/sample/simple_server.c,v 1.3 1996/03/11 09:21:49 bg Exp $";
+"Bones$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/appl/sample/simple_server.c,v 1.3 1996/03/11 09:21:49 bg Exp $";
 #endif	lint
 
 #include <mit-copyright.h>
