@@ -39,7 +39,7 @@ static char copyright[] =
 
 #include <config.h>
 
-RCSID("$Id: main.c,v 1.10 1996/02/11 17:22:54 bg Exp $");
+RCSID("$Id: main.c,v 1.11 1996/05/05 04:33:54 assar Exp $");
 
 #include <sys/types.h>
 #include <string.h>
@@ -130,11 +130,14 @@ int main(int argc, char **argv)
 	 */
 	autologin = -1;
 
-	while ((ch = getopt(argc, argv, "8EKLS:X:acde:fFk:l:n:rt:x")) != EOF) {
+	while ((ch = getopt(argc, argv, "78EKLS:X:acde:fFk:l:n:rt:x")) != EOF) {
 		switch(ch) {
 		case '8':
 			eight = 3;	/* binary output and input */
 			break;
+		case '7':
+			eight = 0;
+			break;
 		case 'E':
 			rlogin = escape = _POSIX_VDISABLE;
 			break;
