@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: utility.c,v 1.9 1996/02/10 11:49:57 assar Exp $");
+RCSID("$Id: utility.c,v 1.10 1996/03/27 11:42:44 bg Exp $");
 
 #define PRINTOPTIONS
 #include "telnetd.h"
@@ -97,7 +97,7 @@ stilloob(int s)
     do {
 	FD_ZERO(&excepts);
 	FD_SET(s, &excepts);
-	value = select(s+1, (fd_set *)0, (fd_set *)0, &excepts, &timeout);
+	value = select(s+1, 0, 0, &excepts, &timeout);
     } while ((value == -1) && (errno == EINTR));
 
     if (value < 0) {
