@@ -35,7 +35,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kadmin/admin_server.c,v 1.22 1996/03/24 06:57:41 assar Exp $");
+RCSID("$Id: admin_server.c,v 1.25 1996/04/23 07:11:22 d91-jda Exp $");
 
 /* Almost all procs and such need this, so it is global */
 admin_params prm;		/* The command line parameters struct */
@@ -51,21 +51,13 @@ static int *pidarray = (int *)0;
 
 static exit_now = 0;
 
-/*
- * Use return_retsigtype(0) macro when returning from a signal handler.
- */
-#ifdef VOID_RETSIGTYPE
-#define return_retsigtype(x) return
-#else
-#define return_retsigtype(x) return (RETSIGTYPE)(x)
-#endif
 
 static
 RETSIGTYPE
 doexit(int sig)
 {
     exit_now = 1;
-    return_retsigtype(0);
+    SIGRETURN(0);
 }
    
 static
@@ -93,11 +85,11 @@ do_child(int sig)
 		|| WIFSIGNALED(status))
 	      k_log("child %d: termsig %d, retcode %d", pid,
 		  WTERMSIG(status), WEXITSTATUS(status));
-	    return_retsigtype(0);
+	    SIGRETURN(0);
 	}
     k_log("child %d not in list: termsig %d, retcode %d", pid,
 	WTERMSIG(status), WEXITSTATUS(status));
-    return_retsigtype(0);
+    SIGRETURN(0);
 }
 
 static void
@@ -307,8 +299,8 @@ kadm_listen(void)
 	    return(0);
 	}
 	readfds = mask;
-	if ((found = select(admin_fd+1,&readfds,(fd_set *)0,
-			    (fd_set *)0, (struct timeval *)0)) == 0)
+	if ((found = select(admin_fd+1, &readfds, 0,
+			    0, (struct timeval *)0)) == 0)
 	    continue;			/* no things read */
 	if (found < 0) {
 	    if (errno != EINTR)
