@@ -1,7 +1,7 @@
 /*
  * This software may now be redistributed outside the US.
  *
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil.c,v $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kadmin/ksrvutil.c,v $
  *
  * $Locker:  $
  */
@@ -299,7 +299,7 @@ get_svc_new_key(des_cblock *new_key, char *sname, char *sinst, char *srealm, cha
 }
 
 static void
-get_key_from_password(des_cblock (*key))
+get_key_from_password(des_cblock (*key), char *cellname)
 {
     char password[MAX_KPW_LEN];	/* storage for the password */
 
@@ -310,7 +310,10 @@ get_key_from_password(des_cblock (*key))
     (void) bzero((char *) key, sizeof(des_cblock));
     key[0] = (unsigned char) 1;
 #else /* NOENCRYPTION */
-    (void) des_string_to_key(password, key);
+    if (strlen(cellname) == 0)
+      (void) des_string_to_key(password, key);
+    else
+      (void) afs_string_to_key(password, cellname, key);
 #endif /* NOENCRYPTION */
     (void) bzero((char *)password, sizeof(password));
 }    
@@ -320,6 +323,7 @@ usage(void)
 {
     (void) fprintf(stderr, "Usage: ksrvutil [-f keyfile] [-i] [-k] ");
     (void) fprintf(stderr, "[-p principal] [-r realm] ");
+    (void) fprintf(stderr, "[-c AFS cellname] ");
     (void) fprintf(stderr, "{list | change | add | get}\n");
     (void) fprintf(stderr, "   -i causes the program to ask for ");
     (void) fprintf(stderr, "confirmation before changing keys.\n");
@@ -346,6 +350,7 @@ main(int argc, char **argv)
     int work_keyfile_fd = -1;	/* Initialize so that */
     int backup_keyfile_fd = -1;	/* compiler doesn't complain */
     char local_realm[REALM_SZ];	/* local kerberos realm */
+    char cellname[1024];         /* AFS cell name */
     int c;
     int interactive = FALSE;
     int list = FALSE;
@@ -376,7 +381,7 @@ main(int argc, char **argv)
     if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
 	(void) strcpy(local_realm, "NO.DEFAULT.REALM");
     
-    while((c = getopt(argc, argv, "ikf:p:r:")) != EOF) {
+    while((c = getopt(argc, argv, "ikc:f:p:r:")) != EOF) {
 	 switch (c) {
 	      case 'i':
 	      interactive++;
@@ -384,6 +389,9 @@ main(int argc, char **argv)
 	      case 'k':
 	      key++;
 	      break;
+	      case 'c':
+	      (void) strcpy(cellname, optarg);
+	      break;
 	      case 'f':
 	      (void) strcpy(keyfile, optarg);
 	      break;
@@ -552,9 +560,9 @@ main(int argc, char **argv)
 		     */
 		    des_init_random_number_generator(&old_key);
 		    {
-		        unsigned char seqnum[8];
-			des_rand_data(seqnum, sizeof(seqnum));
-			des_set_sequence_number(seqnum);
+		        des_cblock seqnum;
+			des_generate_random_block(&seqnum);
+			des_set_sequence_number((unsigned char *)&seqnum);
 		    }
 		    /* 
 		     * Pick a new key and determine whether or not
@@ -638,7 +646,7 @@ main(int argc, char **argv)
 		print_name(sname, sinst, srealm);
 		(void) printf("; version %d\n", key_vno);
 	    } while (!yn("Is this correct?"));
-	    get_key_from_password(&new_key);
+	    get_key_from_password(&new_key, cellname);
 	    if (key) {
 		(void) printf("Key: ");
 		print_key(new_key);
