@@ -1,6 +1,6 @@
 #include "kadm_locl.h"
 
-RCSID("$Id: pw_check.c,v 1.5 1996/02/07 11:00:15 bg Exp $");
+RCSID("$Id: pw_check.c,v 1.9 1996/03/22 14:15:51 bg Exp $");
 
 /*
  * kadm_pw_check
@@ -18,20 +18,27 @@ kadm_pw_check(char *pw, des_cblock *newkey, char **pw_msg,
   des_cblock pwkey;
   int status=KADM_SUCCESS;
   
+  if (pw == NULL || *pw == '\0')
+    return status;		/* XXX - Change this later */
+
 #ifndef NO_PW_CHECK
   *pw_msg = NULL;
-  des_string_to_key(pw, &pwkey);
-  if(memcmp(pwkey, *newkey, sizeof(pwkey))){
-    /* no password or bad key */
-    status=KADM_PW_MISMATCH;
-  } else if(strlen(pw) < MIN_KPW_LEN){
-    status = KADM_INSECURE_PW;
-    *pw_msg="Password is too short";
-  }
+  des_string_to_key(pw, &pwkey); /* Check AFS string to key also! */
+  if (memcmp(pwkey, *newkey, sizeof(pwkey)) != 0)
+    {
+      /* no password or bad key */
+      status=KADM_PW_MISMATCH;
+      *pw_msg = "Password doesn't match supplied DES key";
+    }
+  else if (strlen(pw) < MIN_KPW_LEN)
+    {
+      status = KADM_INSECURE_PW;
+      *pw_msg="Password is too short";
+    }
   
 #ifdef DICTPATH
   *pw_msg = FascistCheck(pw, DICTPATH, strings);
-  if(*pw_msg)
+  if (*pw_msg)
     return KADM_INSECURE_PW;
 #endif
 
