@@ -10,9 +10,10 @@
 
 #include "kuser_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/kuser/klist.c,v 1.8 1996/03/11 09:22:03 bg Exp $");
+RCSID("$Id: klist.c,v 1.11 1996/05/05 04:34:44 d91-jda Exp $");
 
-char   *whoami;			/* What was I invoked as?? */
+static char   *whoami;			/* What was I invoked as?? */
+static int option_verbose = 0;
 
 static char *
 short_date(int32_t dp)
@@ -102,8 +103,9 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	       (prealm[0] ? "@" : ""), prealm);
     while ((k_errno = tf_get_cred(&c)) == KSUCCESS) {
 	if (!tgt_test && long_form && header) {
-	    printf("%-15s  %-15s  %s\n",
-		   "  Issued", "  Expires", "  Principal");
+	    printf("%-15s  %-15s  %s%s\n",
+		   "  Issued", "  Expires", "  Principal", 
+		   option_verbose ? " (kvno)" : "");
 	    header = 0;
 	}
 	if (tgt_test) {
@@ -129,7 +131,7 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	printf("%s%s%s%s%s",
 	       c.service, (c.instance[0] ? "." : ""), c.instance,
 	       (c.realm[0] ? "@" : ""), c.realm); 
-	if(long_form)
+	if(long_form && option_verbose)
 	  printf(" (%d)", c.kvno);
 	printf("\n");
     }
@@ -211,7 +213,7 @@ static void
 usage(void)
 {
     fprintf(stderr,
-        "Usage: %s [ -s | -t ] [ -f filename ] [ -srvtab ]\n", whoami);
+        "Usage: %s [ -v | -s | -t ] [ -f filename ] [ -srvtab ]\n", whoami);
     exit(1);
 }
 
@@ -228,6 +230,10 @@ main(int argc, char **argv)
     whoami = (cp = strrchr(*argv, '/')) ? cp + 1 : *argv;
 
     while (*(++argv)) {
+	if (!strcmp(*argv, "-v")) {
+	    option_verbose = 1;
+	    continue;
+	}
 	if (!strcmp(*argv, "-s")) {
 	    long_form = 0;
 	    continue;
