@@ -1,5 +1,5 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v $
  * $Author: bg $
  *
  * Copyright 1988 by the Massachusetts Institute of Technology. 
@@ -18,7 +18,7 @@
 #include <conf.h>
 
 const char rcsid[] =
-    "$Header: /src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v 1.3 1996/03/11 09:22:04 bg Exp $";
+    "$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/kuser/ksrvtgt.c,v 1.3 1996/03/11 09:22:04 bg Exp $";
 
 main(argc,argv)
     int argc;
