@@ -1,7 +1,10 @@
 /*
  * This section is for machines using single entry point AFS syscalls!
- * or
+ * and/or
  * This section is for machines using multiple entry point AFS syscalls!
+ *
+ * SunOS 4 is an example of single entry point and sgi of multiple
+ * entry point syscalls.
  */
 
 #if SunOS == 4
@@ -12,7 +15,7 @@
 #define AFS_SYSCALL	105
 #endif
 
-#if defined(hpux)
+#if defined(__hpux)
 #define AFS_SYSCALL	50
 #define AFS_SYSCALL2	49
 #endif
@@ -21,7 +24,7 @@
 /* _AIX is too weird */
 #endif
 
-#if defined(sgi)
+#if defined(__sgi)
 #define AFS_PIOCTL      (64+1000)
 #define AFS_SETPAG      (65+1000)
 #endif
