@@ -1,7 +1,7 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/kdc.h,v $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/kdc.h,v $
  * $Author: d91-jda $
- * $Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/kdc.h,v 1.3 1996/03/24 06:46:31 d91-jda Exp $
+ * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/kdc.h,v 1.5 1996/05/05 05:06:48 d91-jda Exp $
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -24,7 +24,11 @@
 
 /* Don't depend on this! */
 #ifndef MKEYFILE
+#if 0
 #define MKEYFILE	"/var/kerberos/master-key"
+#else
+#define MKEYFILE	"/.k"
+#endif
 #endif
 #ifndef K_LOGFIL
 #define K_LOGFIL	"/var/log/kpropd.log"
