@@ -1,7 +1,7 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v $
- * $Author: d91-jda $
- * $Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v 1.8 1996/03/24 06:46:53 d91-jda Exp $ 
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v $
+ * $Author: bg $
+ * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v 1.9 1996/03/28 11:10:47 bg Exp $ 
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -117,6 +117,11 @@ int kdb_get_new_master_key __P((des_cblock *, des_key_schedule, int));
 int kdb_kstash __P((des_cblock *, char *));
 long kdb_verify_master_key __P((des_cblock *, struct des_ks_struct *, FILE *));
 
+int kdb_new_get_new_master_key __P((des_cblock *key,
+				    des_key_schedule schedule, int verify));
+int kdb_get_master_key __P((int prompt, des_cblock *master_key, 
+			    struct des_ks_struct *master_key_sched));
+
 
 #include <stdio.h>
 long kdb_verify_master_key __P((des_cblock *, des_key_schedule, FILE *));
