@@ -26,12 +26,16 @@ or implied warranty.
 
 #include "kdb_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_dbm.c,v 1.11 1996/03/24 07:07:19 assar Exp $");
+RCSID("$Id: krb_dbm.c,v 1.14 1996/05/03 23:14:59 assar Exp $");
 
 #ifdef NDBM
 #include <ndbm.h>
 #else /*NDBM*/
+#if defined(HAVE_DBM_H)
 #include <dbm.h>
+#elif defined(HAVE_RPCSVC_DBM_H)
+#include <rpcsvc/dbm.h>
+#endif
 #endif /*NDBM*/
 
 #define KERB_DB_MAX_RETRY 5
@@ -496,15 +500,12 @@ kerb_db_create(char *db_name)
  * necessarily know to complete the transaction the rename, but...
  */
 
-int
-kerb_db_rename __P((char *from, char *to));
-
 int
 kerb_db_rename(char *from, char *to)
 {
 #ifdef HAVE_NEW_DB
     char *fromdb = gen_dbsuffix (from, ".db");
-    char *todb = gen_dbsuffix (from, ".db");
+    char *todb = gen_dbsuffix (to, ".db");
 #else
     char *fromdir = gen_dbsuffix (from, ".dir");
     char *todir = gen_dbsuffix (to, ".dir");
