@@ -26,15 +26,10 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/getrealm.c,v 1.5 1996/02/07 10:48:40 d91-jda Exp $");
+RCSID("$Id: getrealm.c,v 1.8 1996/04/26 11:39:23 d91-jda Exp $");
 
 #define MATCH_SUBDOMAINS        0
 
-/* for Ultrix and friends ... */
-#ifndef MAXHOSTNAMELEN
-#define MAXHOSTNAMELEN 64
-#endif
-
 /*
  * krb_realmofhost.
  * Given a fully-qualified domain-style primary host name,
@@ -86,11 +81,15 @@ krb_realmofhost(char *host)
 {
 	char *domain;
 	FILE *trans_file;
-	char trans_host[MAXHOSTNAMELEN+1];
+	char trans_host[MaxHostNameLen+1];
 	char trans_realm[REALM_SZ+1];
 	int retval;
 
-	domain = strchr(host, '.');
+	char phost[MaxHostNameLen+1];
+	
+	k_name_to_name(host, phost);
+	
+	domain = strchr(phost, '.');
 
 	/* prepare default */
 	if (domain) {
@@ -118,9 +117,9 @@ krb_realmofhost(char *host)
 			}
 			continue;	/* ignore broken lines */
 		}
-		trans_host[MAXHOSTNAMELEN] = '\0';
+		trans_host[MaxHostNameLen] = '\0';
 		trans_realm[REALM_SZ] = '\0';
-		if (!strcasecmp(trans_host, host)) {
+		if (!strcasecmp(trans_host, phost)) {
 			/* exact match of hostname, so return the realm */
 			(void) strcpy(ret_realm, trans_realm);
 			fclose(trans_file);
