@@ -1,7 +1,7 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v $
- * $Author: bg $
- * $Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v 1.18 1996/03/11 09:22:06 bg Exp $ 
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v $
+ * $Author: d91-jda $
+ * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/krb/krb.h,v 1.23 1996/04/29 08:03:38 d91-jda Exp $ 
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -18,6 +18,10 @@
 #include <sys/bitypes.h>
 #include <sys/cdefs.h>
 
+#ifndef __P
+#define __P(x) x
+#endif
+
 /* Need some defs from des.h	 */
 #include <des.h>
 
@@ -347,10 +351,11 @@ typedef struct msg_dat MSG_DAT;
 #define   K_LOCK_NB   4		/* Don't block when locking */
 #define   K_LOCK_UN   8		/* Unlock */
 int k_flock __P((int fd, int operation));
+#if !defined(__hppa) && !defined(__GNUC_)
 struct tm;
+#endif
 struct tm *k_localtime __P((u_int32_t *));
 const char *k_strerror __P((int errnum));
-int k_setreuid(int r, int e);
 int k_getsockinst __P((int fd, char *inst));
 int k_getportbyname __P((const char *service, const char *proto, int default_port));
 
@@ -385,8 +390,10 @@ int tf_save_cred __P((char *, char *, char *, unsigned char *, int , int , KTEXT
 void tf_close __P((void));
 
 /* Private communication */
+#if !defined(__hppa) && !defined(__GNUC_)
 struct sockaddr_in;
-int32_t krb_mk_priv __P((u_char *, u_char *, u_int32_t , struct des_ks_struct *, des_cblock *, struct sockaddr_in *, struct sockaddr_in *));
+#endif
+int32_t krb_mk_priv __P((void *, void *, u_int32_t, struct des_ks_struct *, des_cblock *, struct sockaddr_in *, struct sockaddr_in *));
 int32_t krb_rd_priv __P((void *, u_int32_t, struct des_ks_struct *, des_cblock *, struct sockaddr_in *, struct sockaddr_in *, MSG_DAT *));
 
 /* Misc */
@@ -425,6 +432,7 @@ int krb_get_krbhst __P((char *, char *, int));
 int krb_get_krbhst __P((char *, char *, int));
 int krb_get_krbhst __P((char *, char *, int));
 int krb_get_lrealm __P((char *, int));
+char *krb_get_default_realm __P((void));
 int krb_get_pw_in_tkt __P((char *, char *, char *, char *, char *, int, char *));
 int krb_get_svc_in_tkt __P((char *, char *, char *, char *, char *, int, char *));
 int krb_get_tf_fullname __P((char *, char *, char *, char *));
@@ -445,7 +453,7 @@ int save_credentials __P((char *, char *, char *, unsigned char *, int , int , K
 int send_to_kdc __P((KTEXT , KTEXT , char *));
 
 int32_t krb_mk_err __P((u_char *, int32_t, char *));
-int32_t krb_mk_safe __P((u_char *, u_char *, u_int32_t, des_cblock *, struct sockaddr_in *, struct sockaddr_in *));
+int32_t krb_mk_safe __P((void *, void *, u_int32_t, des_cblock *, struct sockaddr_in *, struct sockaddr_in *));
 int32_t krb_rd_safe __P((void *, u_int32_t, des_cblock *, struct sockaddr_in *, struct sockaddr_in *, MSG_DAT *));
 
 void ad_print __P((AUTH_DAT *));
