@@ -56,6 +56,6 @@ int new_log __P((time_t, char *));
 char *month_sname __P((int));
 int fgetst __P((FILE *, char *, int));
 
-int k_setreuid(int, int);
+int k_name_to_name(char*, char*);
 
 #endif /*  __krb_locl_h */
