@@ -31,7 +31,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/kuserok.c,v 1.5 1996/03/24 15:12:56 bg Exp $");
+RCSID("$Id: kuserok.c,v 1.9 1996/04/29 17:07:07 d91-jda Exp $");
 
 #include <pwd.h>
 #include <sys/param.h>
@@ -119,21 +119,20 @@ kuserok(AUTH_DAT *kdata, char *luser)
     (void) strcpy(pbuf, pwd->pw_dir);
     (void) strcat(pbuf, "/.klogin");
 
-    if (access(pbuf, F_OK)) {	 /* not accessible */
+    fp = fopen(pbuf, "r");
+    if(fp == NULL){
 	/*
 	 * if he's trying to log in as himself, and there is no .klogin file,
 	 * let him.  To find out, call
 	 * krb_kntoln to convert the triple in kdata to a name which we can
 	 * string compare. 
 	 */
-	if (!krb_kntoln(kdata, kuser) && (strcmp(kuser, luser) == 0)) {
-	    return(OK);
-	}
-    }
-    /* open ~/.klogin */
-    if ((fp = fopen(pbuf, "r")) == NULL) {
-	return(NOTOK);
+	if(errno == ENOENT)
+	    if(!krb_kntoln(kdata, kuser) && (strcmp(kuser, luser) == 0))
+		return OK;
+	return NOTOK;
     }
+
     /*
      * security:  if the user does not own his own .klogin file,
      * do not grant access
