@@ -36,7 +36,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/rd_safe.c,v 1.8 1996/03/18 16:32:50 bg Exp $");
+RCSID("$Id: rd_safe.c,v 1.12 1996/04/24 09:34:46 assar Exp $");
 
 /* system include files */
 #include <sys/types.h>
@@ -146,13 +146,13 @@ krb_rd_safe protocol err sizeof(src_addr) != sizeof(struct in_addr)");
     /* check direction bit is the sign bit */
     /* For compatibility with broken old code, compares are done in VAX 
        byte order (LSBFIRST) */ 
-    if (lsb_net_ulong_less(sender->sin_addr.s_addr,
-			   receiver->sin_addr.s_addr)==-1) 
+    if (krb_lsb_antinet_ulong_less(sender->sin_addr.s_addr,
+			   receiver->sin_addr.s_addr) < 0)
 	/* src < recv */ 
 	m_data->time_sec =  - m_data->time_sec; 
-    else if (lsb_net_ulong_less(sender->sin_addr.s_addr, 
+    else if (krb_lsb_antinet_ulong_less(sender->sin_addr.s_addr, 
 				receiver->sin_addr.s_addr)==0) 
-	if (lsb_net_ushort_less(sender->sin_port,receiver->sin_port)==-1)
+	if (krb_lsb_antinet_ushort_less(sender->sin_port,receiver->sin_port) < 0)
 	    /* src < recv */
 	    m_data->time_sec =  - m_data->time_sec; 
 
