@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/send_to_kdc.c,v 1.12 1996/03/24 15:12:57 bg Exp $");
+RCSID("$Id: send_to_kdc.c,v 1.15 1996/03/28 11:10:52 bg Exp $");
 
 #define S_AD_SZ sizeof(struct sockaddr_in)
 
@@ -153,7 +153,7 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
         if (!host)
             continue;
         no_host = 0;    /* found at least one */
-	while (p = *(host->h_addr_list)++) {
+	while ((p = *(host->h_addr_list)++)) {
           n_hosts++;
   	  addrlist = realloc(addrlist, sizeof(*addrlist) * (n_hosts+1));
 	  if (addrlist == NULL)
@@ -252,7 +252,7 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
     errno = 0;
     /* select - either recv is ready, or timeout */
     /* see if timeout or error or wrong descriptor */
-    if (select(f + 1, &readfds, (fd_set *)0, (fd_set *)0, &timeout) < 1
+    if (select(f + 1, &readfds, 0, 0, &timeout) < 1
         || !FD_ISSET(f, &readfds)) {
 #ifndef KRB_NDEB
         if (krb_debug) {
