@@ -9,7 +9,7 @@
 #include "config.h"
 #include "protos.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/server/kerberos.c,v 1.21 1996/03/24 06:58:04 assar Exp $");
+RCSID("$Id: kerberos.c,v 1.26 1996/05/04 02:04:25 d91-jda Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -132,7 +132,7 @@ kerb_err_reply(int f, struct sockaddr_in *client, KTEXT pkt, long int err, char
     strcat(e_msg, string);
     cr_err_reply(e_pkt, req_name_ptr, req_inst_ptr, req_realm_ptr,
 		 req_time_ws, err, e_msg);
-    sendto(f, e_pkt->dat, e_pkt->length, 0, (struct sockaddr *)client,
+    sendto(f, (char*)e_pkt->dat, e_pkt->length, 0, (struct sockaddr *)client,
 	   S_AD_SZ);
 }
 
@@ -279,7 +279,6 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
     AUTH_DAT ad_st;
     AUTH_DAT *ad = &ad_st;
 
-
     static struct in_addr client_host;
     static int msg_byte_order;
     static int swap_bytes;
@@ -290,8 +289,6 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
     des_key_schedule key_s;
     char   *ptr;
 
-
-
     ciph->length = 0;
 
     client_host = client->sin_addr;
@@ -419,7 +416,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    rpkt = create_auth_reply(req_name_ptr, req_inst_ptr,
 		req_realm_ptr, req_time_ws, 0, a_name_data.exp_date,
 		a_name_data.key_version, ciph);
-	    sendto(f, rpkt->dat, rpkt->length, 0, (struct sockaddr *)client,
+	    sendto(f, (char*)rpkt->dat, rpkt->length, 0, (struct sockaddr *)client,
 		   S_AD_SZ);
 	    bzero(&a_name_data, sizeof(a_name_data));
 	    bzero(&s_name_data, sizeof(s_name_data));
@@ -438,6 +435,10 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    tk->length = 0;
 	    k_flags = 0;	/* various kerberos flags */
 
+	    req_name_ptr = NULL;
+	    req_inst_ptr = NULL;
+	    req_realm_ptr = NULL;
+
 	    auth->length = 4 + strlen((char *)pkt->dat + 3);
 	    auth->length += (int) *(pkt->dat + auth->length) +
 		(int) *(pkt->dat + auth->length + 1) + 2;
@@ -445,7 +446,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    bcopy(pkt->dat, auth->dat, auth->length);
 
 	    strncpy(tktrlm, (char *)auth->dat + 3, REALM_SZ);
-	    if (kerno = set_tgtkey(tktrlm)) {
+	    if ((kerno = set_tgtkey(tktrlm))) {
 		lt = klog(L_ERR_UNK,
 		    "FAILED realm %s unknown. Host: %s ",
 			  tktrlm, inet_ntoa(client_host));
@@ -529,8 +530,8 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    rpkt = create_auth_reply(ad->pname, ad->pinst,
 				     ad->prealm, time_ws,
 				     0, 0, 0, ciph);
-	    sendto(f, rpkt->dat, rpkt->length, 0, (struct sockaddr *)client,
-		   S_AD_SZ);
+	    sendto(f, (char*)rpkt->dat, rpkt->length, 0, 
+		   (struct sockaddr *)client, S_AD_SZ);
 	    bzero(&s_name_data, sizeof(s_name_data));
 	    break;
 	}
@@ -589,7 +590,8 @@ setup_disc(void)
  * Exit if it is; we don't want to tell lies.
  */
 
-static void check_db_age(void)
+static void
+check_db_age(void)
 {
     long age;
     
@@ -644,8 +646,8 @@ process (int sock)
     KTEXT   pkt = &pkt_st;
 
     fromlen = S_AD_SZ;
-    n = recvfrom(sock, pkt->dat, MAX_PKT_LEN, 0, (struct sockaddr *)&from,
-		 &fromlen);
+    n = recvfrom(sock, (char*)pkt->dat, MAX_PKT_LEN, 0, 
+		 (struct sockaddr *)&from, &fromlen);
     if (n > 0) {
 	 pkt->length = n;
 	 pkt->mbz = 0; /* force zeros to catch runaway strings */
