@@ -1,6 +1,6 @@
 /*
- * $Header: /src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.4 1996/03/10 15:12:46 assar Exp $
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v $
+ * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.5 1996/03/25 13:11:39 bg Exp $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v $
  * $Locker:  $
  *
  * Copyright 1986, 1987, 1988 by MIT Information Systems and
@@ -19,7 +19,7 @@
 #include "mit-sipb-copyright.h"
 #include "internal.h"
 
-RCSID("$Header: /src/packages/kth-krb/SourceRepository/krb4/util/et/init_et.c,v 1.4 1996/03/10 15:12:46 assar Exp $");
+RCSID("$Id: init_et.c,v 1.5 1996/03/25 13:11:39 bg Exp $");
 
 struct foobar {
     struct et_list etl;
