@@ -1,7 +1,7 @@
 /*
  *------------------------------------------------------------------
  *
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/util/ss/test.c,v $
+ * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/test.c,v $
  * $Revision: 1.2 $
  * $Date: 1996/02/11 00:40:59 $
  * $State: Exp $
@@ -14,7 +14,7 @@
 
 #ifndef lint
 static char const rcsid_test_c[] =
-    "$Header: /src/packages/kth-krb/SourceRepository/krb4/util/ss/test.c,v 1.2 1996/02/11 00:40:59 assar Exp $";
+    "$Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/util/ss/test.c,v 1.2 1996/02/11 00:40:59 assar Exp $";
 #endif /* lint */
 
 #include <stdio.h>
